@@ -1,6 +1,6 @@
 # ABSTRACT: generate charts on the command line.
 package App::CSV2Chart;
-$App::CSV2Chart::VERSION = '0.6.0';
+$App::CSV2Chart::VERSION = '0.6.1';
 use strict;
 use warnings;
 
@@ -16,7 +16,7 @@ __END__
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 SYNOPSIS
 
@@ -38,9 +38,9 @@ csv2chart - command line utility to convert CSV data to a graphical chart
 
 But see L<https://github.com/watson/chart-csv/issues/4> .
 
-=back
+=item * L<Text::CSV>
 
-L<Text::CSV> .
+=back
 
 =head1 COPYRIGHT & LICENSE
 
